# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 18:37:03 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"SFAuthorization",
        b"obtainWithRight:flags:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"SFAuthorization",
        b"obtainWithRights:flags:environment:authorizedRights:error:",
        {
            "retval": {"type": "Z"},
            "arguments": {5: {"type_modifier": b"o"}, 6: {"type_modifier": b"o"}},
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
